==> haskell-x11-xft-0.3.1-36-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-x11-xft.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: X11-xft
version: 0.3.1
id: X11-xft-0.3.1-2RD5bsRcgnFFo2Kc2faM0W
key: X11-xft-0.3.1-2RD5bsRcgnFFo2Kc2faM0W
license: LicenseRef-LGPL
maintainer: clemens@endorphin.org
author: Clemens Fruhwirth
synopsis: Bindings to the Xft, X Free Type interface library, and some Xrender parts
description:
    Bindings to the Xft, X Free Type interface library, and some Xrender parts
category: Graphics
abi: c45d447b0ff1fef5c9d7478293b768d7
exposed: True
exposed-modules:
    Graphics.X11.Xft Graphics.X11.Xrender
import-dirs: /usr/lib/ghc-8.4.3/site-local/X11-xft-0.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/X11-xft-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/X11-xft-0.3.1
hs-libraries: HSX11-xft-0.3.1-2RD5bsRcgnFFo2Kc2faM0W
extra-libraries:
    Xft
include-dirs: /usr/include/freetype2 /usr/include/libpng16
              /usr/include/harfbuzz /usr/include/glib-2.0
              /usr/lib/glib-2.0/include /usr/include/uuid
depends:
    X11-1.9-72pXPIWotOnFLesP8FyvXP base-4.11.1.0
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
abi-depends: X11-1.9-72pXPIWotOnFLesP8FyvXP=94a8bc4506bd0ff77d8e8d5ee1695391
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=03d2b6edbbe4042d502eabc2ba3840fc
haddock-interfaces: /usr/share/doc/haskell-x11-xft/html/X11-xft.haddock
haddock-html: /usr/share/doc/haskell-x11-xft/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x11-xft-0.3.1-37-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-x11-xft.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: X11-xft
version: 0.3.1
id: X11-xft-0.3.1-E2YofuHBPu4DXAPLYyOuZS
key: X11-xft-0.3.1-E2YofuHBPu4DXAPLYyOuZS
license: LicenseRef-LGPL
maintainer: clemens@endorphin.org
author: Clemens Fruhwirth
synopsis: Bindings to the Xft, X Free Type interface library, and some Xrender parts
description:
    Bindings to the Xft, X Free Type interface library, and some Xrender parts
category: Graphics
abi: 879ab035cdc5ac4e99e329642e7a9ef2
exposed: True
exposed-modules:
    Graphics.X11.Xft Graphics.X11.Xrender
import-dirs: /usr/lib/ghc-8.6.1/site-local/X11-xft-0.3.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/X11-xft-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/X11-xft-0.3.1
hs-libraries: HSX11-xft-0.3.1-E2YofuHBPu4DXAPLYyOuZS
extra-libraries:
    Xft
include-dirs: /usr/include/freetype2 /usr/include/libpng16
              /usr/include/harfbuzz /usr/include/glib-2.0
              /usr/lib/glib-2.0/include /usr/include/uuid
depends:
    X11-1.9-1jVNltY9i4MFrKqIqKnIHs base-4.12.0.0
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-x11-xft/html/X11-xft.haddock
haddock-html: /usr/share/doc/haskell-x11-xft/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
